# Purpose

Adds two `pyfsdb` utilities for converting too and from parquet files.

`pyfsdb` is intended to be light weight, and parquet support requires
both `pyarrow` and `fastparquet` and are thus distributed separately.

# Installation

    pipx install pyfsdb_parquet

# See also

The [main pyfsdb](https://github.com/hardaker/pyfsdb) documentation.
